/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */

package app;

import java.awt.Dimension;
import java.awt.event.ActionEvent;
import java.awt.event.ActionListener;

import javax.swing.JDialog;
import javax.swing.JLabel;
import javax.swing.JButton;
import javax.swing.JTextField;
import javax.swing.JTextArea;
import javax.swing.JSpinner;
import javax.swing.JPanel;
import javax.swing.JScrollPane;
import javax.swing.SpinnerNumberModel;
import javax.swing.WindowConstants;

/**
 * Class which represents the author information window
 * 
 * @author Markus Waltl
 * @version 1.0
 */
public class AuthorInformationWindow extends JDialog implements ActionListener {
	private static final long serialVersionUID = -6849109948331066711L;
	private JButton cancelButton;
	private JButton okButton;
	private JLabel lblVersion;
	private JLabel lblConfidence;
	private JLabel lblCreatorName;
	private JLabel lblCreatorOrganization;
	private JTextField fieldVersion;
	private JSpinner spinnerConfidence;
	private JTextField fieldCreatorName;
	private JTextField fieldCreatorOrganization;
	private JTextArea areaComment;
	private JPanel mainPanel;
	private JScrollPane commentScroll;
	private int returnVal = -1;

	/**
	 * Constructor
	 */
	public AuthorInformationWindow() {
		setModal(true);
		initComponents();
		setLocation(50, 50);
		setSize(500, 310);
		setPreferredSize(new Dimension(500, 310));
	}
	
	/**
	 * Constructor
	 * @param name String to fill in
	 * @param org String to fill in
	 * @param version String to fill in
	 * @param confidence float to fill in
	 * @param comment String to fill in
	 */
	public AuthorInformationWindow(String name, String org, String version, float confidence, String comment) {
		this();
		fieldVersion.setText(version);
		fieldCreatorName.setText(name);
		fieldCreatorOrganization.setText(org);
		double val = confidence;
		spinnerConfidence.setValue(val);
		
		if (comment != null && !comment.equals(""))
			areaComment.setText(comment);
	}
	
	/**
	 * Method for showing the dialog
	 * @return message value
	 */
	public int showDialog() {
        setVisible(true);
        return returnVal;
	} 
		
	/**
	 * Method for initializing the components
	 */
	private void initComponents() {
		mainPanel = new JPanel();
		cancelButton = new JButton();
		okButton = new JButton();
		lblVersion = new JLabel("Version:");
		lblConfidence = new JLabel("Confidence:");
		lblCreatorName = new JLabel("Name:");
		lblCreatorOrganization = new JLabel("Organization:");
		fieldVersion = new JTextField();
		spinnerConfidence = new JSpinner();
		fieldCreatorName = new JTextField();
		fieldCreatorOrganization = new JTextField();
		areaComment = new JTextArea();
		commentScroll = new JScrollPane();
		
		cancelButton.setText("Cancel");
		cancelButton.setActionCommand("cancelButton");
		cancelButton.setName("cancelButton");
		cancelButton.addActionListener(this);
		
		okButton.setText("OK");
		okButton.setActionCommand("okButton");
		okButton.setName("okButton");
		okButton.addActionListener(this);
		
		spinnerConfidence.setName("spinnerConfidence");
		spinnerConfidence.setPreferredSize(new Dimension(50, 20));
		spinnerConfidence.setModel(new SpinnerNumberModel(0.0, 0.0, 1.0, 0.1));
		
		fieldVersion.setPreferredSize(new Dimension(80, 20));
		fieldVersion.setName("fieldVersion");
		
		fieldCreatorName.setPreferredSize(new Dimension(400, 20));
		fieldCreatorName.setName("fieldCreatorName");
		
		fieldCreatorOrganization.setPreferredSize(new Dimension(380, 20));
		fieldCreatorOrganization.setName("fieldCreatorOrganization");
		
		areaComment.setName("areaComment");
		areaComment.setText("Enter here your comments");
		areaComment.setRows(10);
		areaComment.setColumns(40);
		
		commentScroll.setViewportView(areaComment);
		
		mainPanel.add(lblCreatorName);
		mainPanel.add(fieldCreatorName);
		mainPanel.add(lblCreatorOrganization);
		mainPanel.add(fieldCreatorOrganization);
		mainPanel.add(lblVersion);
		mainPanel.add(fieldVersion);
		mainPanel.add(lblConfidence);
		mainPanel.add(spinnerConfidence);
		mainPanel.add(commentScroll);
		mainPanel.add(okButton);
		mainPanel.add(cancelButton);
		
		add(mainPanel);
        
        setDefaultCloseOperation(WindowConstants.DISPOSE_ON_CLOSE);
		setTitle("SEVino - Author information");
		setName("SEVinoAuthor");
		setResizable(false);
	}

	/**
	 * Method for performing a button action
	 * @param e ActionEvent to perform
	 */
	public void actionPerformed(ActionEvent e) {
		if (e.getActionCommand().equals("okButton")) {
			returnVal = 1;
			dispose();
		}
		else if (e.getActionCommand().equals("cancelButton")) {
			returnVal = -1;
			dispose();
		}		
	}
	
	/**
	 * Method for retrieving the creator name
	 * @return String with creator name
	 */
	public String getCreatorName() {
		return fieldCreatorName.getText();
	}
	
	/**
	 * Method for retrieving the comment
	 * @return String with the comment
	 */
	public String getComment() {
		return areaComment.getText();
	}
	
	/**
	 * Method for retrieving the confidence value
	 * @return float with the value
	 */
	public float getConfidence() {
		return new Float((Double)spinnerConfidence.getValue());
	}
	
	/**
	 * Method for retrieving the organization
	 * @return String with the organization
	 */
	public String getCreatorOrganization() {
		return fieldCreatorOrganization.getText();
	}
	
	/**
	 * Method for retrieving the version
	 * @return String with the version
	 */
	public String getVersion() {
		return fieldVersion.getText();
	}
}
