/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */

package app;

import java.util.Vector;

import lib.ConfigElement;
import io.LoadConfig;

/**
 * The main class of the application.
 * 
 * @author Markus Waltl
 * @version 1.0
 */
public class SEVinoApp {

    /**
     * Main method launching the application.
     * @param args String[] with arguments
     */
	public static void main(String[] args) {
		
		// version check
		String version = System.getProperty("java.version");
        System.out.println("Your JRE version: " + version);
        char minor = version.charAt(2);
        int pos = version.indexOf("_");
        int update = -1;
       
        if (pos != -1) {
    	   try {
    		   update = Integer.valueOf(version.substring(pos+1));
    	   } catch (NumberFormatException e) { }
        }
       
        if(minor < '6') {
    	   System.out.println("\nYou need at least JRE 1.6.0_17 to run this program!");
    	   return;
        }
        else {
    	   if (minor == '6' && update < 17) {
    		   System.out.println("\nYou need at least JRE 1.6.0_17 to run this program!");
        	   return;
    	   }
        }

		
		String configFile = "";
		
		if (args.length > 0) {
			if (args[0].equalsIgnoreCase("-H")) {
				printUsage();
				return;
			}
			else {
				configFile = args[0];
			}	
		}		
		
		LoadConfig lc = new LoadConfig();
   		Vector<ConfigElement> configElements = lc.load(configFile);
		
   		if (configElements == null) {
   			System.out.println("An error occured during config processing!");
   			System.exit(1);
   		}
   		
		SEVinoView gui = new SEVinoView(configElements);
		gui.setVisible(true);
    }
	
	/**
	 * Method for printing the usage
	 */
	public static void printUsage() {
		System.out.println("Usage:");
		System.out.println("SEVino [<config>] -H");
		System.out.println("===================================");
		System.out.println("<config>: config file to use");
		System.out.println("-H:       this help");
	}
}
