/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */

package io;

import java.io.BufferedInputStream;
//import java.io.DataInputStream;
import java.io.DataOutputStream;
import java.io.File;
import java.io.FileInputStream;
import java.io.IOException;
import java.io.InputStream;
import java.io.OutputStreamWriter;
import java.io.Writer;
import java.net.InetAddress;
import java.net.Socket;

/**
 * Class for uploading a file to a server
 * 
 * @author Markus Waltl <markus.waltl@itec.uni-klu.ac.at> 
 *
 */
public class UploadFile {
	
	/**
	 * Method for uploading a file with a given file path
	 * @param server String with the server address
	 * @param port int with the port to use
	 * @param path String with the path on the server
	 * @param filename String with the name to be stored on the server
	 * @param sourceFile String with the path to the file to upload
	 * @throws IOException if an error during upload occurred
	 */
	public static void upload(String server, int port, String path, String filename, String sourceFile) throws IOException {
		if (sourceFile != null && !sourceFile.equals("")) {
			File file = new File(sourceFile);
		    FileInputStream fis = null;
		    BufferedInputStream bis = null;

		    fis = new FileInputStream(file);

		    // Here BufferedInputStream is added for fast reading.
		    bis = new BufferedInputStream(fis);

		    upload(server, port, path, filename, bis);

		    // dispose all the resources after using them.
		    fis.close();
		    bis.close();
		}
		else
			System.out.println("Source file cannot be empty!");
	}
	
	/**
	 * Method for uploading a file with a given input stream
	 * @param server String with the server address
	 * @param port int with the port to use
	 * @param path String with the path on the server
	 * @param filename String with the name to be stored on the server
	 * @param source InputStream with the content to upload
	 * @throws IOException if an error during upload occurred
	 */
	public static void upload(String server, int port, String path, String filename, InputStream source) throws IOException {
		if (server != null && !server.equals("") && filename != null && !filename.equals("") && path != null && 
				!path.equals("") && port > 0 && source != null) {	
			InetAddress addr = InetAddress.getByName(server);
			Socket socket = new Socket(addr, port);

			// File To Upload
			BufferedInputStream bis = new BufferedInputStream(source);
			int dataSize = bis.available();
			byte[] data = new byte[dataSize];
			bis.read(data);
			
			DataOutputStream raw = new DataOutputStream(socket.getOutputStream());
			Writer wr = new OutputStreamWriter(raw);

			String command =
			      "--567835794568\r\n"
			    + "Content-Disposition: form-data; name=\"file\"; filename=\""
			    + filename + "\"\r\n"
			    + "Content-Type: application/octet-stream\r\n"
			    + "\r\n";

			String trail = "\r\n--567835794568--\r\n";

			String header =
			 "POST " + path + " HTTP/1.0\r\n"
			 + "Content-Type: multipart/form-data; boundary=567835794568\r\n"
			 + "Content-Length: " + (dataSize + command.length() + trail.length()) + "\r\n"
			 + "\r\n";

			wr.write(header);
			wr.write(command);
			wr.flush();
			
			int index = 0;
	        int size = 1024;
	        do {          
	            if((index + size) > data.length) {
	                size = data.length - index;
	            }
	            
	            raw.write(data, index, size);
	            index += size;
	        } while(index < data.length);
			
			raw.flush( );
			wr.write(trail);
			wr.flush( );

			wr.close();
			raw.close();
			bis.close();
			
			/*DataInputStream dis = new DataInputStream(socket.getInputStream());
			
			int val = -1;
			while((val = dis.read()) > -1) {
				System.out.print(val);
			}*/ // closed to fast because CMS needs time to extract information
			
			socket.close();
	    }
		else
			System.out.println("Output file or server address not given!");
	}
}
