/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package lib;

/**
 * AVFileFilter
 * 
 * Class for setting the A/V filter for the filechooser
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class AVFileFilter extends javax.swing.filechooser.FileFilter 
{
	String[] allowedFiles = new String[]{"avi", "divx", "mpg", "mpeg", "mpe", "m1v", "m2v", "mpv2", "mp2v", "m2p", "vob", "evo", "mod",
		"ts", "m2ts", "m2t", "mts", "pva", "tp", "tpr", "mp4", "m4v", "mp4v", "mpv4", "hdmov", "mov", "qt",
		"3gp", "3gpp", "3g2", "3gp2", "mkv", "webm", "ogm", "ogv", "flv", "wmv", "amv", "mp3", "ogg", "oga",
		"mka", "m4a", "aac", "flac", "wv", "mpc", "ofr", "ofs", "ape", "apl", "alac", "amr", "ac4", "dts",
		"it", "mo3", "mtm", "s3m", "umx", "xm"};
	
	/**
	 * Constructor
	 */
	public AVFileFilter() 
	{
	}

    /**
     * Method for checking if file should be accepted
     * 
     * @param file file to check
     * @return true if file is accepted else false
     */
	public boolean accept(java.io.File file) 
	{
		boolean retValue = false;
		
		for (int i = 0; i < allowedFiles.length && !retValue; i++) {
			if ((file.getName()).toLowerCase().endsWith(allowedFiles[i]) || (file.isDirectory()))
				retValue = true;					
		}
		return retValue;
	}

    /**
     * Returns a string which descripes
     * the filter in the file chooser
     * 
     * @return String with description
     */
	public String getDescription() 
	{
		return new String("All supported files");
	}
}
