/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package lib;

/**
 * Class which represents a bar in the effect panel
 * 
 * @author Markus Waltl 
 * @version 1.0
 */
public class BarElement implements Comparable<BarElement> {
	private ColorRectangle colorRectangle = null;
	private EffectElement effectElement = null;
	
	/**
	 * Constructor
	 */
	public BarElement() { }
	
	/**
	 * Constructor
	 * @param cr ColorRectangle to use
	 * @param ee EffectElement to use
	 */
	public BarElement(ColorRectangle cr, EffectElement ee) {
		colorRectangle = cr;
		effectElement = ee;
	}
	
	/**
	 * Method for retrieving the color rectangle
	 * @return ColorRectangle used
	 */
	public ColorRectangle getColorRectangle() {
		return colorRectangle;
	}
	
	/**
	 * Method for setting the color rectangle
	 * @param colorRectangle ColorRectangle to use
	 */
	public void setColorRectangle(ColorRectangle colorRectangle) {
		this.colorRectangle = colorRectangle;
	}
	
	/**
	 * Method for retrieving the effect element
	 * @return EffectElement used
	 */
	public EffectElement getEffectElement() {
		return effectElement;
	}
	
	/**
	 * Method for setting the effect element
	 * @param effectElement EffectElement to use
	 */
	public void setEffectElement(EffectElement effectElement) {
		this.effectElement = effectElement;
	}

	/**
	 * Method for comparing two bar elements
	 * @param be BarElement to compare with
	 * @return 0 if equal, -1 or 1 if not equal
	 */
	public int compareTo(BarElement be) {
		if (colorRectangle != null && be != null && be.getColorRectangle() != null)
			return this.colorRectangle.compareTo(be.getColorRectangle());
		else
			return 0;
		}
}
