/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package lib;

import javax.swing.JTextField;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;
import javax.swing.text.PlainDocument;

/**
 * Class for representing a textfield with only floats
 * Based on: http://www.java2s.com/Code/Java/Swing-JFC/Textfieldonlyacceptsnumbers.htm
 * 
 * @author Markus Waltl
 * @version 1.0
 */
public class FloatField extends JTextField {
	private static final long serialVersionUID = -5722471250302391238L;

	/**
	 * Constructor
	 */
	public FloatField() {
		super();
	}
	
	/**
	 * Constructor
	 * @param defval float with default value
	 * @param size int size of field
	 */
	public FloatField(float defval, int size) {
		super("" + defval, size);
	}

	protected Document createDefaultModel() {
		return new FloatDocument();
	}

	public boolean isValid() {
		try {
			if (getDocument() != null) {
				Float.parseFloat(getText());
			
				/*if (value > 1.0f || value < 0.00000000f)
					return false;*/
			
				return true;
			}
			else
				return false;
		} catch (NumberFormatException e) {
			return false;
		}
	}

	/**
	 * Method for retrieving the value of the field
	 * @return float with value
	 */
	public float getValue() {
		try {
			return Float.parseFloat(getText());
		} catch (NumberFormatException e) {
			return 0.0f;
		}
	}

	/**
	 * Inner class which represents the document structure
	 * Taken from: http://www.java2s.com/Code/Java/Swing-JFC/Textfieldonlyacceptsnumbers.htm
	 * 
	 * @author Markus Waltl
	 * @version 1.0
	 */
	class FloatDocument extends PlainDocument {
		private static final long serialVersionUID = 2058037015639126396L;

		public void insertString(int offs, String str, AttributeSet a)
				throws BadLocationException {
			if (str == null)
				return;
			String oldString = getText(0, getLength());
			String newString = oldString.substring(0, offs) + str
					+ oldString.substring(offs);
			try {
				if (newString.equals(""))
					return;
				
				Float.parseFloat(newString);
				
				//if (value > 1.0f || value < 0.00000000f)
				//	return;
				
				int pos = newString.indexOf(".");
				if (pos > -1) {
					newString = newString.substring(pos+1);
					if (newString.length() > 8)
						return;
				}
				
				super.insertString(offs, str, a);
			} catch (NumberFormatException e) { }
		}
	}
}
