/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package lib;

import javax.swing.JTextField;
import javax.swing.text.AttributeSet;
import javax.swing.text.BadLocationException;
import javax.swing.text.Document;
import javax.swing.text.PlainDocument;

/**
 * Class for representing a textfield with only integers
 * Taken from: http://www.java2s.com/Code/Java/Swing-JFC/Textfieldonlyacceptsnumbers.htm
 * 
 * @author Markus Waltl
 * @version 1.0
 */
public class IntField extends JTextField {
	private static final long serialVersionUID = -6416211496413802030L;

	/**
	 * Constructor
	 */
	public IntField() {
		super();
	}
	
	/**
	 * Constructor
	 * @param defval int with default value
	 * @param size int size of field
	 */
	public IntField(int defval, int size) {
		super("" + defval, size);
	}

	protected Document createDefaultModel() {
		return new IntDocument();
	}

	public boolean isValid() {
		try {
			if (getDocument() != null) {
				Integer.parseInt(getText());
				return true;
			}
			else
				return false;
		} catch (NumberFormatException e) {
			return false;
		}
	}

	/**
	 * Method for retrieving the value of the field
	 * @return int with value
	 */
	public int getValue() {
		try {
			return Integer.parseInt(getText());
		} catch (NumberFormatException e) {
			return 0;
		}
	}

	/**
	 * Inner class which represents the document structure
	 * Taken from: http://www.java2s.com/Code/Java/Swing-JFC/Textfieldonlyacceptsnumbers.htm
	 * 
	 * @author Markus Waltl
	 * @version 1.0
	 */
	class IntDocument extends PlainDocument {
		private static final long serialVersionUID = 5808379987305172213L;

		public void insertString(int offs, String str, AttributeSet a)
				throws BadLocationException {
			if (str == null)
				return;
			String oldString = getText(0, getLength());
			String newString = oldString.substring(0, offs) + str
					+ oldString.substring(offs);
			try {
		        Integer.parseInt(newString + "0");
		        super.insertString(offs, str, a);
		      } catch (NumberFormatException e) {
		    }
		}
	}

}
