/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package lib;

import java.awt.Graphics;
import java.awt.Graphics2D;
import java.awt.Rectangle;
import java.awt.image.BufferedImage;
import javax.swing.JPanel;

/**
 * Painter
 * 
 * Class for representing a bitmap panel
 * 
 * @author Markus Waltl (Alpen-Adria-Universitaet Klagenfurt)
 * @version 1.0
 */
public class Painter extends JPanel {
	private static final long serialVersionUID = -4118435394104958406L;
	private BufferedImage image_ = null;
	private Rectangle imageRect_ = null;
	
	/**
	 * Constructor
	 */
	public Painter() {
	}
	
	/**
	 * Method for setting an image
	 * @param image BufferedImage to be set
	 */
	public void setImage(BufferedImage image) {
		image_ = image;
		imageRect_ = new Rectangle(this.getHeight(), this.getWidth());
		repaint();
	}
	
	/**
	 * Method for painting the component
	 */
	protected void paintComponent( Graphics g ) { 
		super.paintComponent( g );
		Graphics2D g2d = (Graphics2D)g;
		if (image_ != null) {
			g2d.drawImage(image_, 0, 0, imageRect_.height, imageRect_.width, this );
		}
	}
}
