/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package lib;

import java.awt.Color;
import java.awt.Component;
import java.awt.Graphics;
import java.awt.Insets;

import javax.swing.border.Border;

/**
 * Draws a little border around the Ruler.
 * Original ruler written by Scott Violet (taken from: http://java.sun.com/products/jfc/tsc/articles/text/tabs/)
 * 
 * extracted from original example for using in other areas
 * 
 * @author Markus Waltl
 * @version 1.0
 */
public class RulerBorder implements Border {
	protected static final Insets DefaultInsets = new Insets(2, 0, 4, 0);

	/**
	 * Paints the border for the specified component with the specified 
	 * position and size.
	 * @param c the component for which this border is being painted
	 * @param g the paint graphics
	 * @param x the x position of the painted border
	 * @param y the y position of the painted border
	 * @param width the width of the painted border
	 * @param height the height of the painted border
	 */
	public void paintBorder(Component c, Graphics g, int x, int y,
			int width, int height) {
		g.setColor(Color.darkGray);
		g.drawLine(x, y + 1, x + width, y + 1);
		g.setColor(Color.lightGray);
		g.drawLine(x, y, x + width, y);
		g.fillRect(x, y + height - 3, width, 2);
	}

	/**
	 * Returns the insets of the border.  
	 * @param c the component for which this border insets value applies
	 */
	public Insets getBorderInsets(Component c) {
		return (Insets) DefaultInsets.clone();
	}

	/**
	 * Returns whether or not the border is opaque.  If the border
	 * is opaque, it is responsible for filling in it's own
	 * background when painting.
	 */
	public boolean isBorderOpaque() {
		return false;
	}
}