/*
 * This file is part of SEVino.
 *
 * SEVino is free software: you can redistribute it and/or modify
 * it under the terms of the GNU General Public License as published by
 * the Free Software Foundation, either version 3 of the License, or
 * (at your option) any later version.
 *
 * SEVino is distributed in the hope that it will be useful,
 * but WITHOUT ANY WARRANTY; without even the implied warranty of
 * MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the
 * GNU General Public License for more details.
 *
 * You should have received a copy of the GNU General Public License
 * along with SEVino.  If not, see <http://www.gnu.org/licenses/>.
 * 
 * Copyright 2008, 2009, 2010, 2011 Alpen-Adria-Universitaet Klagenfurt, Markus Waltl.
 */
package lib;

import java.awt.Dimension;
import java.awt.image.BufferedImage;
import java.io.IOException;
import java.util.Collections;
import java.util.Hashtable;
import java.util.Iterator;
import java.util.Vector;

import app.SEVinoView;

/**
 * Class providing a shot detection
 * @author Markus Waltl
 *
 */
public class ShotsThread extends Thread {
	private ShotDetection sd = null;
	private boolean stopped = false;
	private SEVinoView gui_ = null;
	private String curVideoFile = "";
	
	/**
	 * Constructor
	 * @param video String to the video file
	 * @param gui SEVinoView object for providing information
	 */
	public ShotsThread(String video, SEVinoView gui) {
		curVideoFile = video;
		gui_ = gui;
		try {
			sd = new ShotDetection(curVideoFile, 10, gui_);
		} catch (IOException e) {
			e.printStackTrace();
		}
	}
	
	/**
	 * Method for stopping the shot detection thread
	 */
	public void stopThread() {
		if (sd != null) {
			stopped = true;
			sd.stopDetection();
		}
	}
	
	public void run() {
		sd.startDetection();
		
		if (!stopped) {
			gui_.timeSlider.setMaximum((int)Math.round((sd.getDuration()*10)));
			gui_.timeSlider.setValue(0);
			gui_.curTimeLabel.setText("00:00:00");
			gui_.durationLabel.setText(sd.getDurationString());
			gui_.bitrateLabel.setText(sd.getBitrate());
			gui_.codecLabel.setText(sd.getDecoder() + ", " + sd.getFormat());
			if (sd.getDimension() != null && sd.getDimension().length() <= 20)
				gui_.resolutionLabel.setText(sd.getDimension() + ", " + sd.getFPS());
			else if (sd.getDimension() != null)
				gui_.resolutionLabel.setText(sd.getDimension().substring(0, 20) + ", " + sd.getFPS());
				
			//gui_.videoPanel.setVideoDuration(sd.getDuration());
			gui_.timeSlider.setValue(0);
			gui_.timeList_ = null;
									
			Hashtable<Double, BufferedImage> imageList = sd.getShots();
			Vector<Double> v = new Vector<Double>(imageList.keySet());
			Collections.sort(v);
			gui_.timeList_ = v;
			Iterator<Double> it = v.iterator();
			while (it.hasNext()) {
				Double key = (Double) it.next();
				BufferedImage image = imageList.get(key);
				Painter pan = new Painter();
				pan.setName("shot" + key);
				pan.setToolTipText("Time: " + key);
				pan.addMouseListener(gui_);
				pan.setSize(60, 45);
				pan.setPreferredSize(new Dimension(60, 45));
				//pan.setBorder(javax.swing.BorderFactory.createEtchedBorder());
				pan.setImage(image);
				gui_.shotPanels.add(pan);
				gui_.shotPanel.add(pan);
			}
			    
			int width = imageList.size()*65;
			
			if (width > 800)
				gui_.shotPanel.setPreferredSize(new Dimension(width, 50));
			
			double duration = sd.getDuration();
			double durationInPixel = Math.floor(duration*70);
			double scrollBarMax = Math.floor((duration+0.05)*70); //scroll bars have other dimensions
			//if (durationInPixel > 725) {	// TODO: remove this and try to make the panels left aligned				
				Dimension layerDimension = gui_.rightEffectPanel.getPreferredSize();
				layerDimension.width = (int)durationInPixel;
				gui_.rightEffectPanel.setPreferredSize(layerDimension);
				Dimension layerDimension2 = gui_.ruler.getPreferredSize();
				layerDimension2.width = (int)durationInPixel;
				gui_.ruler.setPreferredSize(layerDimension2);
				
				for (int i = 0; i < gui_.effectTracks_.size(); i++) {
					EffectTrack e = gui_.effectTracks_.elementAt(i);
					EffectPanel bar = e.getEffectBarPanel();
					bar.setPreferredSize(new Dimension((int)durationInPixel, 20));
				}
				
				// update horizontal scroll at effects tracks + ruler
				gui_.rightEffectPanel.revalidate();
				gui_.ruler.revalidate();
				gui_.rightEffectLayer.getHorizontalScrollBar().setValue(0);
				gui_.rulerPane.getHorizontalScrollBar().setValue(0);
				gui_.trackHorizontalScroll.setValue(0);
				
				gui_.trackHorizontalScroll.setMaximum((int)scrollBarMax - gui_.rightEffectLayer.getWidth());
				gui_.rulerPane.getHorizontalScrollBar().setMaximum((int)scrollBarMax - gui_.rightEffectLayer.getWidth());
			//}
								
			gui_.shotPanel.revalidate();
			gui_.playButton.setEnabled(true);
			gui_.trackHorizontalScroll.setEnabled(true);
		}
	}
}